==> zio-aws-rds_3-5.17.127.2-sources.jar: zio/aws/rds/model/CreateDbInstanceReadReplicaResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateDbInstanceReadReplicaResponse(
    dbInstance: scala.Option[zio.aws.rds.model.DBInstance] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.CreateDbInstanceReadReplicaResponse = {
    import CreateDbInstanceReadReplicaResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.CreateDbInstanceReadReplicaResponse
      .builder()
      .optionallyWith(dbInstance.map(value => value.buildAwsValue()))(
        _.dbInstance
      )
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.CreateDbInstanceReadReplicaResponse.ReadOnly =
    zio.aws.rds.model.CreateDbInstanceReadReplicaResponse.wrap(buildAwsValue())
}
object CreateDbInstanceReadReplicaResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.CreateDbInstanceReadReplicaResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.CreateDbInstanceReadReplicaResponse =
      zio.aws.rds.model.CreateDbInstanceReadReplicaResponse(
        dbInstance.map(value => value.asEditable)
      )
    def dbInstance: scala.Option[zio.aws.rds.model.DBInstance.ReadOnly]
    def getDbInstance
        : ZIO[Any, AwsError, zio.aws.rds.model.DBInstance.ReadOnly] =
      AwsError.unwrapOptionField("dbInstance", dbInstance)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.CreateDbInstanceReadReplicaResponse
  ) extends zio.aws.rds.model.CreateDbInstanceReadReplicaResponse.ReadOnly {
    override val dbInstance
        : scala.Option[zio.aws.rds.model.DBInstance.ReadOnly] = scala
      .Option(impl.dbInstance())
      .map(value => zio.aws.rds.model.DBInstance.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.CreateDbInstanceReadReplicaResponse
  ): zio.aws.rds.model.CreateDbInstanceReadReplicaResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rds_3-5.17.196.1-sources.jar: zio/aws/rds/model/CreateDbInstanceReadReplicaResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateDbInstanceReadReplicaResponse(
    dbInstance: Optional[zio.aws.rds.model.DBInstance] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.CreateDbInstanceReadReplicaResponse = {
    import CreateDbInstanceReadReplicaResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.CreateDbInstanceReadReplicaResponse
      .builder()
      .optionallyWith(dbInstance.map(value => value.buildAwsValue()))(
        _.dbInstance
      )
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.CreateDbInstanceReadReplicaResponse.ReadOnly =
    zio.aws.rds.model.CreateDbInstanceReadReplicaResponse.wrap(buildAwsValue())
}
object CreateDbInstanceReadReplicaResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.CreateDbInstanceReadReplicaResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.CreateDbInstanceReadReplicaResponse =
      zio.aws.rds.model.CreateDbInstanceReadReplicaResponse(
        dbInstance.map(value => value.asEditable)
      )
    def dbInstance: Optional[zio.aws.rds.model.DBInstance.ReadOnly]
    def getDbInstance
        : ZIO[Any, AwsError, zio.aws.rds.model.DBInstance.ReadOnly] =
      AwsError.unwrapOptionField("dbInstance", dbInstance)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.CreateDbInstanceReadReplicaResponse
  ) extends zio.aws.rds.model.CreateDbInstanceReadReplicaResponse.ReadOnly {
    override val dbInstance: Optional[zio.aws.rds.model.DBInstance.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbInstance())
        .map(value => zio.aws.rds.model.DBInstance.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.CreateDbInstanceReadReplicaResponse
  ): zio.aws.rds.model.CreateDbInstanceReadReplicaResponse.ReadOnly =
    new Wrapper(impl)
}
